@@ -54,24 +54,20 @@
 - \ref manager.c Main manager code file
  */
 
-#define AMI_VERSION                     "5.0.5"
+#define AMI_VERSION                     "7.0.1"
 #define DEFAULT_MANAGER_PORT 5038	/* Default port for Asterisk management via TCP */
 #define DEFAULT_MANAGER_TLS_PORT 5039	/* Default port for Asterisk management via TCP */
 
 /*! \name Constant return values
- * \note Currently, returning anything other than zero causes the session to terminate.
- *
- * @{
+ *\note Currently, returning anything other than zero causes the session to terminate.
  */
+/*@{ */
 #define	AMI_SUCCESS	(0)
 #define	AMI_DESTROY	(-1)
+/*@} */
 
-/*! @} */
-
-/*! \name Manager event classes
- *
- * @{
- */
+/*! \name Manager event classes */
+/*@{ */
 #define EVENT_FLAG_SYSTEM           (1 << 0) /* System events such as module load/unload */
 #define EVENT_FLAG_CALL             (1 << 1) /* Call event, such as state change, etc */
 #define EVENT_FLAG_LOG              (1 << 2) /* Log events */
@@ -93,8 +89,7 @@
 #define EVENT_FLAG_SECURITY         (1 << 18) /* Security Message as AMI Event */
 /*XXX Why shifted by 30? XXX */
 #define EVENT_FLAG_MESSAGE          (1 << 30) /* MESSAGE events. */
-
-/*! @} */
+/*@} */
 
 /*! \brief Export manager structures */
 #define AST_MAX_MANHEADERS 128
@@ -178,7 +173,7 @@ struct manager_action {
 	 * \brief TRUE if the AMI action is registered and the callback can be called.
 	 *
 	 * \note Needed to prevent a race between calling the callback
-	 * function and unregistering the AMI action object.
+	 * function and unregestring the AMI action object.
 	 */
 	unsigned int registered:1;
 };
@@ -274,7 +269,7 @@ int __ast_manager_event_multichan(int category, const char *event, int chancount
 		struct ast_channel **chans, const char *file, int line, const char *func,
 		const char *contents, ...) __attribute__((format(printf, 8, 9)));
 
-/*! \brief Get header from manager transaction */
+/*! \brief Get header from mananger transaction */
 const char *astman_get_header(const struct message *m, char *var);
 
 /*! \brief Get a linked list of the Variable: headers
@@ -314,6 +309,8 @@ void astman_send_ack(struct mansession *s, const struct message *m, char *msg);
  *
  * \note You need to call astman_send_list_complete_start() and
  * astman_send_list_complete_end() to send the AMI list completion event.
+ *
+ * \return Nothing
  */
 void astman_send_listack(struct mansession *s, const struct message *m, char *msg, char *listflag);
 
@@ -332,6 +329,8 @@ void astman_send_listack(struct mansession *s, const struct message *m, char *ms
  * \note Between calling astman_send_list_complete_start() and
  * astman_send_list_complete_end() you can add additonal headers
  * using astman_append().
+ *
+ * \return Nothing
  */
 void astman_send_list_complete_start(struct mansession *s, const struct message *m, const char *event_name, int count);
 
@@ -347,24 +346,14 @@ void astman_send_list_complete_start(struct mansession *s, const struct message
  * \note Between calling astman_send_list_complete_start() and
  * astman_send_list_complete_end() you can add additonal headers
  * using astman_append().
+ *
+ * \return Nothing
  */
 void astman_send_list_complete_end(struct mansession *s);
 
-/*!
- * \brief Enable/disable the inclusion of 'dangerous' configurations outside
- * of the ast_config_AST_CONFIG_DIR
- *
- * This function can globally enable/disable the loading of configuration files
- * outside of ast_config_AST_CONFIG_DIR.
- *
- * \param new_live_dangerously If true, enable the access of files outside
- * ast_config_AST_CONFIG_DIR from astman.
- */
-void astman_live_dangerously(int new_live_dangerously);
-
 void __attribute__((format(printf, 2, 3))) astman_append(struct mansession *s, const char *fmt, ...);
 
-/*! \brief Determine if a manager session ident is authenticated */
+/*! \brief Determinie if a manager session ident is authenticated */
 int astman_is_authed(uint32_t ident);
 
 /*!
@@ -389,7 +378,7 @@ int astman_datastore_remove(struct mansession *s, struct ast_datastore *datastor
 /*!
  * \brief Find a datastore on a session
  *
- * \return pointer to the datastore if found
+ * \retval pointer to the datastore if found
  * \retval NULL if not found
  * \since 1.6.1
  */
@@ -422,7 +411,7 @@ struct ast_channel_snapshot;
  * \param prefix What to prepend to the channel fields
  *
  * \retval NULL on error
- * \return ast_str* on success (must be ast_freed by caller)
+ * \retval ast_str* on success (must be ast_freed by caller)
  */
 struct ast_str *ast_manager_build_channel_state_string_prefix(
 		const struct ast_channel_snapshot *snapshot,
@@ -436,7 +425,7 @@ struct ast_str *ast_manager_build_channel_state_string_prefix(
  *                 body
  *
  * \retval NULL on error
- * \return ast_str* on success (must be ast_freed by caller)
+ * \retval ast_str* on success (must be ast_freed by caller)
  */
 struct ast_str *ast_manager_build_channel_state_string(
 		const struct ast_channel_snapshot *snapshot);
@@ -464,7 +453,7 @@ struct ast_json;
  * \param exclusion_cb A \ref key_exclusion_cb pointer to a function that will exclude
  * keys from the final AMI string
  *
- * \return A malloc'd \ref ast_str object. Callers of this function should free
+ * \retval A malloc'd \ref ast_str object. Callers of this function should free
  * the returned \ref ast_str object
  * \retval NULL on error
  */
@@ -479,7 +468,7 @@ struct ast_str *ast_manager_str_from_json_object(struct ast_json *blob, key_excl
  * \param prefix What to prepend to the bridge fields
  *
  * \retval NULL on error
- * \return ast_str* on success (must be ast_freed by caller)
+ * \retval ast_str* on success (must be ast_freed by caller)
  */
 struct ast_str *ast_manager_build_bridge_state_string_prefix(
 	const struct ast_bridge_snapshot *snapshot,
@@ -493,7 +482,7 @@ struct ast_str *ast_manager_build_bridge_state_string_prefix(
  *                 body
  *
  * \retval NULL on error
- * \return ast_str* on success (must be ast_freed by caller)
+ * \retval ast_str* on success (must be ast_freed by caller)
  */
 struct ast_str *ast_manager_build_bridge_state_string(
 	const struct ast_bridge_snapshot *snapshot);
@@ -518,8 +507,8 @@ struct ast_manager_event_blob {
  * \param extra_fields_fmt Format string for extra fields to include.
  *                         Or NO_EXTRA_FIELDS for no extra fields.
  *
- * \return New \ref ast_manager_event_blob object.
- * \retval NULL on error.
+ * \return New \ref ast_manager_snapshot_event object.
+ * \return \c NULL on error.
  */
 struct ast_manager_event_blob *
 __attribute__((format(printf, 3, 4)))
@@ -558,16 +547,16 @@ int manager_mwi_init(void);
 
 /*!
  * \brief Initialize support for AMI channel events.
- * \retval 0 on success.
- * \retval non-zero on error.
+ * \return 0 on success.
+ * \return non-zero on error.
  * \since 12
  */
 int manager_bridging_init(void);
 
 /*!
  * \brief Initialize support for AMI endpoint events.
- * \retval 0 on success.
- * \retval non-zero on error.
+ * \return 0 on success.
+ * \return non-zero on error.
  * \since 12
  */
 int manager_endpoints_init(void);
@@ -584,7 +573,7 @@ int manager_endpoints_init(void);
  * - class_type is the class authorization type for the event
  * - event is a list of key/value tuples to be sent out in the message
  *
- * \return A \ref stasis_message_type for AMI messages
+ * \retval A \ref stasis_message_type for AMI messages
  */
 struct stasis_message_type *ast_manager_get_generic_type(void);
 
@@ -592,7 +581,7 @@ struct stasis_message_type *ast_manager_get_generic_type(void);
  * \since 12
  * \brief Get the \ref stasis topic for AMI
  *
- * \return The \ref stasis topic for AMI
+ * \retval The \ref stasis topic for AMI
  * \retval NULL on error
  */
 struct stasis_topic *ast_manager_get_topic(void);
@@ -606,9 +595,9 @@ struct stasis_topic *ast_manager_get_topic(void);
  * \param obj The event data to be published.
  *
  * Publishes a message to the \ref stasis message bus solely for the consumption of AMI.
- * The message will be of the type provided by \ref ast_manager_get_generic_type, and
- * will be published to the topic provided by \ref ast_manager_get_topic. As such, the
- * JSON must be constructed as defined by the \ref ast_manager_get_generic_type message.
+ * The message will be of the type provided by \ref ast_manager_get_type, and will be
+ * published to the topic provided by \ref ast_manager_get_topic. As such, the JSON must
+ * be constructed as defined by the \ref ast_manager_get_type message.
  */
 void ast_manager_publish_event(const char *type, int class_type, struct ast_json *obj);
 
@@ -616,7 +605,7 @@ void ast_manager_publish_event(const char *type, int class_type, struct ast_json
  * \since 12
  * \brief Get the \ref stasis_message_router for AMI
  *
- * \return The \ref stasis_message_router for AMI
+ * \retval The \ref stasis_message_router for AMI
  * \retval NULL on error
  */
 struct stasis_message_router *ast_manager_get_message_router(void);
