@@ -72,7 +72,7 @@ static int say_stub(struct ast_channel *chan, ...)
  * \param num number to say on the channel
  * \param ints which dtmf to interrupt on
  * \param lang language to speak the number
- * \param options set to 'f' for female, 'm' for male, 'c' for commune, 'n' for neuter, 'p' for plural
+ * \param options set to 'f' for female, 'm' for male, 'c' for commune, 'n' for neuter
  * \details
  * Vocally says a number on a given channel
  * \retval 0 on success
@@ -82,7 +82,7 @@ static int say_stub(struct ast_channel *chan, ...)
 int ast_say_number(struct ast_channel *chan, int num,
 	const char *ints, const char *lang, const char *options);
 
-/* Same as above with audiofd for received audio and returns 1 on ctrlfd being readable */
+/*! \brief Same as \ref ast_say_number() with audiofd for received audio and returns 1 on ctrlfd being readable */
 SAY_EXTERN int (* ast_say_number_full)(struct ast_channel *chan, int num, const char *ints, const char *lang, const char *options, int audiofd, int ctrlfd) SAY_INIT(ast_say_number_full);
 
 /*!
@@ -91,7 +91,7 @@ SAY_EXTERN int (* ast_say_number_full)(struct ast_channel *chan, int num, const
  * \param num number to say on the channel
  * \param ints which dtmf to interrupt on
  * \param lang language to speak the enumeration
- * \param options set to 'f' for female, 'm' for male, 'c' for commune, 'n' for neuter, 'p' for plural
+ * \param options set to 'f' for female, 'm' for male, 'c' for commune, 'n' for neuter
  * \details
  * Vocally says an enumeration on a given channel (first, sencond, third, forth, thirtyfirst, hundredth, ....)
  * Especially useful for dates and messages. Says 'last' if num equals to INT_MAX
@@ -102,6 +102,7 @@ SAY_EXTERN int (* ast_say_number_full)(struct ast_channel *chan, int num, const
 int ast_say_enumeration(struct ast_channel *chan, int num,
 	const char *ints, const char *lang, const char *options);
 
+/*! \brief Same as \ref ast_say_enumeration() with audiofd for received audio and returns 1 on ctrlfd being readable */
 SAY_EXTERN int (* ast_say_enumeration_full)(struct ast_channel *chan, int num, const char *ints, const char *lang, const char *options, int audiofd, int ctrlfd) SAY_INIT(ast_say_enumeration_full);
 
 /*!
@@ -119,6 +120,7 @@ SAY_EXTERN int (* ast_say_enumeration_full)(struct ast_channel *chan, int num, c
 int ast_say_digits(struct ast_channel *chan, int num,
 	const char *ints, const char *lang);
 
+/*! \brief Same as \ref ast_say_digits() with audiofd for received audio and returns 1 on ctrlfd being readable */
 int ast_say_digits_full(struct ast_channel *chan, int num,
 	const char *ints, const char *lang, int audiofd, int ctrlfd);
 
@@ -137,21 +139,32 @@ int ast_say_digits_full(struct ast_channel *chan, int num,
 int ast_say_digit_str(struct ast_channel *chan, const char *num,
 	const char *ints, const char *lang);
 
+/*! \brief Same as \ref ast_say_digit_str() with audiofd for received audio and returns 1 on ctrlfd being readable */
 SAY_EXTERN int (* ast_say_digit_str_full)(struct ast_channel *chan, const char *num, const char *ints, const char *lang, int audiofd, int ctrlfd) SAY_INIT(ast_say_digit_str_full);
 
-/*
+/*! \brief
  * the generic 'say' routine, with the first chars in the string
  * defining the format to use
  */
 SAY_EXTERN int (* ast_say_full)(struct ast_channel *chan, const char *num, const char *ints, const char *lang, const char *options, int audiofd, int ctrlfd) SAY_INIT(ast_say_full);
 
-/*
- * other function to pronounce character and phonetic strings
+/*!
+ * \brief Controls how ast_say_character_str denotes the case of characters in a string
+ */
+enum ast_say_case_sensitivity {
+	AST_SAY_CASE_NONE,  /*!< Do not distinguish case on any letters */
+	AST_SAY_CASE_LOWER, /*!< Denote case only on lower case letters, upper case is assumed otherwise */
+	AST_SAY_CASE_UPPER, /*!< Denote case only on upper case letters, lower case is assumed otherwise */
+	AST_SAY_CASE_ALL,   /*!< Denote case on all letters, upper and lower */
+};
+
+/*! \brief
+ * function to pronounce character and phonetic strings
  */
 int ast_say_character_str(struct ast_channel *chan, const char *num,
-	const char *ints, const char *lang);
+	const char *ints, const char *lang, enum ast_say_case_sensitivity sensitivity);
 
-SAY_EXTERN int (* ast_say_character_str_full)(struct ast_channel *chan, const char *num, const char *ints, const char *lang, int audiofd, int ctrlfd) SAY_INIT(ast_say_character_str_full);
+SAY_EXTERN int (* ast_say_character_str_full)(struct ast_channel *chan, const char *num, const char *ints, const char *lang, enum ast_say_case_sensitivity sensitivity, int audiofd, int ctrlfd) SAY_INIT(ast_say_character_str_full);
 
 int ast_say_phonetic_str(struct ast_channel *chan, const char *num,
 	const char *ints, const char *lang);
